@@ -4,8 +4,9 @@
 ## it under the terms of the GNU General Public License as published
 ## by the Free Software Foundation; version 2 and higer.
 ##
-## Martin Grimme (martin.grimme # gmail.com) 2010LANG_DE = 0x0
+## Martin Grimme (martin.grimme # gmail.com) 2010
 
+LANG_DE = 0x0
 LANG_EN = 0x1
 LANG_IT = 0x2
 LANG_FR = 0x3
